@@ -77,6 +77,10 @@ impl<'a> From<&'a [u8]> for PackedResourcesSource<'a> {
 #[derive(Clone, Debug)]
 pub struct OxidizedPythonInterpreterConfig<'a> {
     /// The path of the currently executing executable.
+    ///
+    /// If not set, [std::env::current_exe()] will be used.
+    ///
+    /// In all cases, the path will be canonicalized.
     pub exe: Option<PathBuf>,
 
     /// The filesystem path from which relative paths will be interpreted.
@@ -295,14 +299,16 @@ impl<'a> OxidizedPythonInterpreterConfig<'a> {
         let exe = if let Some(exe) = self.exe {
             exe
         } else {
-            dunce::canonicalize(
-                std::env::current_exe().map_err(|_| {
-                    NewInterpreterError::Simple("could not obtain current executable")
-                })?,
-            )
-            .map_err(|_| NewInterpreterError::Simple("could not obtain current executable path"))?
+            std::env::current_exe()
+                .map_err(|_| NewInterpreterError::Simple("could not obtain current executable"))?
         };
 
+        // We always canonicalize the current executable because we use path
+        // comparisons in the path hooks importer to assess whether a given sys.path
+        // entry is this executable.
+        let exe = dunce::canonicalize(exe)
+            .map_err(|_| NewInterpreterError::Simple("could not obtain current executable path"))?;
+
         let origin = if let Some(origin) = self.origin {
             origin
         } else {
@@ -328,28 +334,22 @@ impl<'a> OxidizedPythonInterpreterConfig<'a> {
             })
             .collect::<Vec<_>>();
 
-        let module_search_paths = match &self.interpreter_config.module_search_paths {
-            Some(paths) => Some(
-                paths
-                    .iter()
+        let module_search_paths = self
+            .interpreter_config
+            .module_search_paths
+            .as_ref()
+            .map(|x| {
+                x.iter()
                     .map(|p| {
                         PathBuf::from(p.display().to_string().replace("$ORIGIN", &origin_string))
                     })
-                    .collect::<Vec<_>>(),
-            ),
-            None => None,
-        };
+                    .collect::<Vec<_>>()
+            });
 
-        let tcl_library = if let Some(tcl_library) = self.tcl_library {
-            Some(PathBuf::from(
-                tcl_library
-                    .display()
-                    .to_string()
-                    .replace("$ORIGIN", &origin_string),
-            ))
-        } else {
-            None
-        };
+        let tcl_library = self
+            .tcl_library
+            .as_ref()
+            .map(|x| PathBuf::from(x.display().to_string().replace("$ORIGIN", &origin_string)));
 
         Ok(ResolvedOxidizedPythonInterpreterConfig {
             inner: Self {
