@@ -9,10 +9,8 @@ use {
         config::{OxidizedPythonInterpreterConfig, ResolvedOxidizedPythonInterpreterConfig},
         conversion::osstring_to_bytes,
         error::NewInterpreterError,
-        importer::{
-            initialize_path_hooks, replace_meta_path_importers, PyInit_oxidized_importer,
-            OXIDIZED_IMPORTER_NAME, OXIDIZED_IMPORTER_NAME_STR,
-        },
+        extension::{PyInit_oxidized_importer, OXIDIZED_IMPORTER_NAME, OXIDIZED_IMPORTER_NAME_STR},
+        importer::{install_path_hook, remove_external_importers, replace_meta_path_importers},
         osutils::resolve_terminfo_dirs,
         pyalloc::PythonMemoryAllocator,
         python_resources::PythonResourcesState,
@@ -53,7 +51,7 @@ pub struct MainPythonInterpreter<'python, 'interpreter: 'python, 'resources: 'in
     config: ResolvedOxidizedPythonInterpreterConfig<'resources>,
     interpreter_guard: Option<std::sync::MutexGuard<'interpreter, ()>>,
     pub(crate) allocator: Option<PythonMemoryAllocator>,
-    gil: Option<GILGuard>,
+    _gil: Option<GILGuard>,
     py: Option<Python<'python>>,
     /// File to write containing list of modules when the interpreter finalizes.
     write_modules_path: Option<PathBuf>,
@@ -84,7 +82,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
             config,
             interpreter_guard: None,
             allocator: None,
-            gil: None,
+            _gil: None,
             py: None,
             write_modules_path: None,
         };
@@ -189,7 +187,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         let py = unsafe { Python::assume_gil_acquired() };
         self.py = Some(py);
 
-        let finder = if self.config.oxidized_importer {
+        let oxidized_finder = if self.config.oxidized_importer {
             let resources_state = Box::new(PythonResourcesState::try_from(&self.config)?);
 
             let oxidized_importer = py.import(OXIDIZED_IMPORTER_NAME_STR).map_err(|err| {
@@ -233,43 +231,38 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         let sys_module = py
             .import("sys")
             .map_err(|err| NewInterpreterError::new_from_pyerr(py, err, "obtaining sys module"))?;
+
         // When the main initialization ran, it initialized the "external"
-        // importer (importlib._bootstrap_external). Our meta path importer
-        // should have been registered first and would have been used for
-        // all imports, if configured for such.
+        // importer (importlib._bootstrap_external), mutating `sys.meta_path`
+        // and `sys.path_hooks`.
         //
-        // Here, we remove the filesystem importer if we aren't configured
-        // to use it. Ideally there would be a field on PyConfig to disable
-        // just the external importer. But there isn't. The only field
-        // controls both internal and external bootstrap modules and when
-        // set it will disable a lot of "main" initialization.
+        // If enabled, OxidizedFinder should still be the initial entry on
+        // `sys.meta_path`. And if it were capable, OxidizedFinder would have
+        // serviced all imports so far.
+        //
+        // Here, we undo the mutations caused by initializing of the "external"
+        // importers if we're not configured to perform filesystem importing.
+        // Ideally there would be a field on PyConfig to prevent the initializing
+        // of these importers. But there isn't. There is an `_install_importlib`
+        // field. However, when disabled it disables a lot of "main" initialization
+        // and isn't usable for us.
+
         if !self.config.filesystem_importer {
-            let meta_path = sys_module.get(py, "meta_path").map_err(|err| {
-                NewInterpreterError::new_from_pyerr(py, err, "obtaining sys.meta_path")
+            remove_external_importers(py, &sys_module).map_err(|err| {
+                NewInterpreterError::new_from_pyerr(py, err, "removing external importers")
             })?;
-            meta_path
-                .call_method(py, "pop", NoArgs, None)
-                .map_err(|err| {
-                    NewInterpreterError::new_from_pyerr(py, err, "sys.meta_path.pop()")
-                })?;
-        } else if let Some(finder) = finder {
-            // If we have both OxidizedFinder and PathFinder, we tell PathFinder
-            // how to use OxidizedFinder by inserting OxidizedFinder.path_hook
-            // into sys.path_hooks
-            initialize_path_hooks(py, &finder, &sys_module).map_err(|err| {
+        }
+
+        if let Some(finder) = &oxidized_finder {
+            install_path_hook(py, &finder, &sys_module).map_err(|err| {
                 NewInterpreterError::new_from_pyerr(
                     py,
                     err,
                     "installing OxidizedFinder in sys.path_hooks",
                 )
-            })?
+            })?;
         }
 
-        /* Pre-initialization functions we could support:
-         *
-         * PyObject_SetArenaAllocator()
-         */
-
         if self.config.argvb {
             let args_objs = self
                 .config
@@ -361,8 +354,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
                     })?
                     .to_string();
 
-                self.write_modules_path =
-                    Some(PathBuf::from(path).join(format!("modules-{}", uuid_str)));
+                self.write_modules_path = Some(path.join(format!("modules-{}", uuid_str)));
             }
         }
 
@@ -372,7 +364,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
     /// Ensure the Python GIL is released.
     pub fn release_gil(&mut self) {
         self.py = None;
-        self.gil = None;
+        self._gil = None;
     }
 
     /// Ensure the Python GIL is acquired, returning a handle on the interpreter.
@@ -388,7 +380,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
                 let gil = GILGuard::acquire();
                 let py = unsafe { Python::assume_gil_acquired() };
 
-                self.gil = Some(gil);
+                self._gil = Some(gil);
                 self.py = Some(py);
 
                 py
