@@ -28,13 +28,16 @@ use {
     std::{
         borrow::Cow,
         cell::RefCell,
-        collections::{hash_map::Entry, HashMap},
+        collections::{hash_map::Entry, BTreeSet, HashMap},
         convert::TryFrom,
         ffi::CStr,
+        os::raw::c_int,
         path::{Path, PathBuf},
     },
 };
 
+const ENOENT: c_int = 2;
+
 /// Python bytecode optimization level.
 #[derive(Clone, Copy, Debug)]
 pub(crate) enum OptimizeLevel {
@@ -65,6 +68,43 @@ where
         }
 }
 
+/// Whether a resource name matches a package target.
+///
+/// This function is used for filtering through resources at a specific
+/// level in the package hierarchy, as defined by `package_target`.
+///
+/// `None` means the root level and will only yield top-level elements.
+/// `Some(T)` defines a specific package level.
+///
+/// Note that a resource is emitted by its parent. e.g. the `foo` resource
+/// would be emitted by the `None` target and `foo.bar` would be emitted by
+/// the `foo` target.
+///
+/// Targeting resources at specific levels in the package hierarchy is
+/// likely encountered in path entry finders and iter_modules().
+pub(crate) fn name_at_package_hierarchy(fullname: &str, package_target: Option<&str>) -> bool {
+    match package_target {
+        None => !fullname.contains('.'),
+        Some(package) => match fullname.strip_prefix(&format!("{}.", package)) {
+            Some(suffix) => !suffix.contains('.'),
+            None => false,
+        },
+    }
+}
+
+/// Whether a resource name is within a given package hierarchy.
+///
+/// This is like [name_at_package_hierarchy] except non-immediate descendants
+/// of the target package match. The `None` target matches everything.
+/// `fullname == package_target` will never match, as it should be matched
+/// by its parent.
+pub(crate) fn name_within_package_hierarchy(fullname: &str, package_target: Option<&str>) -> bool {
+    match package_target {
+        None => true,
+        Some(package) => fullname.starts_with(&format!("{}.", package)),
+    }
+}
+
 /// Describes the type of an importable Python module.
 #[derive(Debug, PartialEq)]
 pub(crate) enum ModuleFlavor {
@@ -318,20 +358,16 @@ impl<'a> ImportablePythonModule<'a, u8> {
     /// Obtain the filesystem path to this resource to be used for `ModuleSpec.origin`.
     fn origin_path(&self) -> Option<PathBuf> {
         match self.flavor {
-            ModuleFlavor::SourceBytecode => {
-                if let Some(path) = &self.resource.relative_path_module_source {
-                    Some(self.origin.join(path))
-                } else {
-                    None
-                }
-            }
-            ModuleFlavor::Extension => {
-                if let Some(path) = &self.resource.relative_path_extension_module_shared_library {
-                    Some(self.origin.join(path))
-                } else {
-                    None
-                }
-            }
+            ModuleFlavor::SourceBytecode => self
+                .resource
+                .relative_path_module_source
+                .as_ref()
+                .map(|path| self.origin.join(path)),
+            ModuleFlavor::Extension => self
+                .resource
+                .relative_path_extension_module_shared_library
+                .as_ref()
+                .map(|path| self.origin.join(path)),
             _ => None,
         }
     }
@@ -344,11 +380,9 @@ impl<'a> ImportablePythonModule<'a, u8> {
             OptimizeLevel::Two => &self.resource.relative_path_module_bytecode_opt2,
         };
 
-        if let Some(bytecode_path) = bytecode_path {
-            Some(self.origin.join(bytecode_path))
-        } else {
-            None
-        }
+        bytecode_path
+            .as_ref()
+            .map(|bytecode_path| self.origin.join(bytecode_path))
     }
 
     pub fn in_memory_extension_module_shared_library(&self) -> &'a Option<Cow<'a, [u8]>> {
@@ -380,7 +414,7 @@ where
     backing_py_objects: Vec<PyObject>,
 
     /// Holds memory mapped file instances that resources data came from.
-    backing_mmaps: Vec<Box<memmap::Mmap>>,
+    backing_mmaps: Vec<memmap::Mmap>,
 }
 
 impl<'a> Default for PythonResourcesState<'a, u8> {
@@ -482,7 +516,7 @@ impl<'a> PythonResourcesState<'a, u8> {
         let path = path.as_ref();
         let f = std::fs::File::open(path).map_err(|e| e.to_string())?;
 
-        let mapped = Box::new(unsafe { memmap::Mmap::map(&f) }.map_err(|e| e.to_string())?);
+        let mapped = unsafe { memmap::Mmap::map(&f) }.map_err(|e| e.to_string())?;
 
         let data = unsafe { std::slice::from_raw_parts::<u8>(mapped.as_ptr(), mapped.len()) };
 
@@ -790,6 +824,87 @@ impl<'a> PythonResourcesState<'a, u8> {
         Ok(PyList::new(py, &names).into_object())
     }
 
+    /// Whether the given resource name is a directory with resources.
+    pub fn is_package_resource_directory(&self, package: &str, name: &str) -> bool {
+        // Normalize to UNIX style paths.
+        let name = name.replace('\\', "/");
+
+        let prefix = if name.ends_with('/') {
+            name
+        } else {
+            format!("{}/", name)
+        };
+
+        if let Some(entry) = self.resources.get(package) {
+            if let Some(resources) = &entry.in_memory_package_resources {
+                if resources.keys().any(|path| path.starts_with(&prefix)) {
+                    return true;
+                }
+            }
+
+            if let Some(resources) = &entry.relative_path_package_resources {
+                if resources.keys().any(|path| path.starts_with(&prefix)) {
+                    return true;
+                }
+            }
+
+            false
+        } else {
+            false
+        }
+    }
+
+    /// Resolve package resources in a directory.
+    pub fn package_resources_list_directory(&self, package: &str, name: &str) -> Vec<String> {
+        let name = name.replace('\\', "/");
+
+        let prefix = if name.ends_with('/') {
+            Some(name)
+        } else if name.is_empty() {
+            None
+        } else {
+            Some(format!("{}/", name))
+        };
+
+        let filter_map_resource = |path: &'_ Cow<'_, str>| -> Option<String> {
+            match &prefix {
+                Some(prefix) => {
+                    if let Some(name) = path.strip_prefix(prefix) {
+                        if name.contains('/') {
+                            None
+                        } else {
+                            Some(name.to_string())
+                        }
+                    } else {
+                        None
+                    }
+                }
+                None => {
+                    // Empty string input matches root directory.
+                    if path.contains('/') {
+                        None
+                    } else {
+                        Some(path.to_string())
+                    }
+                }
+            }
+        };
+
+        let mut entries = BTreeSet::new();
+
+        if let Some(entry) = self.resources.get(package) {
+            if let Some(resources) = &entry.in_memory_package_resources {
+                entries.extend(resources.keys().filter_map(filter_map_resource));
+            }
+
+            if let Some(resources) = &entry.relative_path_package_resources {
+                entries.extend(resources.keys().filter_map(filter_map_resource));
+            }
+        }
+
+        entries.into_iter().collect::<Vec<_>>()
+    }
+
     /// Attempt to resolve a PyBytes for resource data given a relative path.
     ///
     /// Raises OSerror on failure.
@@ -836,6 +951,7 @@ impl<'a> PythonResourcesState<'a, u8> {
         // this functionality some day. But it should likely never be the default
         // because it goes against the spirit of requiring all resources to be
         // known ahead-of-time.
+
         let native_path = PathBuf::from(path.to_string_lossy(py).to_string());
 
         let (relative_path, check_in_memory, check_relative_path) =
@@ -846,7 +962,7 @@ impl<'a> PythonResourcesState<'a, u8> {
             } else {
                 return Err(PyErr::new::<OSError, _>(
                     py,
-                    (libc::ENOENT, "resource not known", path),
+                    (ENOENT, "resource not known", path),
                 ));
             };
 
@@ -871,7 +987,7 @@ impl<'a> PythonResourcesState<'a, u8> {
             return Err(PyErr::new::<OSError, _>(
                 py,
                 (
-                    libc::ENOENT,
+                    ENOENT,
                     "illegal resource name: missing package component",
                     path,
                 ),
@@ -934,32 +1050,34 @@ impl<'a> PythonResourcesState<'a, u8> {
 
         Err(PyErr::new::<OSError, _>(
             py,
-            (libc::ENOENT, "resource not known", path),
+            (ENOENT, "resource not known", path),
         ))
     }
 
     /// Obtain a PyList of pkgutil.ModuleInfo for known resources.
     ///
     /// This is intended to be used as the implementation for Finder.iter_modules().
-    pub fn pkgutil_modules_infos<P>(
+    ///
+    /// `package_filter` defines the target package to return results for. The
+    /// empty string denotes top-level packages only.
+    pub fn pkgutil_modules_infos(
         &self,
         py: Python,
+        package_filter: Option<&str>,
         prefix: Option<String>,
         optimize_level: OptimizeLevel,
-        predicate: P,
-    ) -> PyResult<PyObject>
-    where
-        P: FnMut(&&Resource<'_, u8>) -> bool,
-    {
+    ) -> PyResult<PyObject> {
         let infos: PyResult<Vec<PyObject>> = self
             .resources
             .values()
             .filter(|r| {
                 r.is_extension_module || (r.is_module && is_module_importable(r, optimize_level))
             })
-            .filter(predicate)
+            .filter(|r| name_at_package_hierarchy(&r.name, package_filter))
             .map(|r| {
-                let name = r.name.rsplit('.').take(1).next().unwrap();
+                // We always take the leaf-most name.
+                let name = r.name.rsplit('.').next().unwrap();
+
                 let name = if let Some(prefix) = &prefix {
                     format!("{}{}", prefix, name)
                 } else {
@@ -1010,7 +1128,7 @@ impl<'a> PythonResourcesState<'a, u8> {
     }
 }
 
-py_class!(pub class OxidizedResource |py| {
+py_class!(pub(crate) class OxidizedResource |py| {
     data resource: RefCell<Resource<'static, u8>>;
 
     def __new__(_cls) -> PyResult<OxidizedResource> {
@@ -1213,7 +1331,7 @@ py_class!(pub class OxidizedResource |py| {
         if let Some(value) = value {
             self.resource(py).borrow_mut().in_memory_package_resources =
                 pyobject_optional_resources_map_to_owned_bytes(py, &value)?
-                    .map(|x| x.into_iter().map(|(k, v)| (Cow::Owned(k.to_owned()), Cow::Owned(v.to_owned()))).collect());
+                    .map(|x| x.into_iter().map(|(k, v)| (Cow::Owned(k), Cow::Owned(v))).collect());
 
             Ok(())
         } else {
@@ -1232,7 +1350,7 @@ py_class!(pub class OxidizedResource |py| {
             self.resource(py).borrow_mut().in_memory_distribution_resources =
                 pyobject_optional_resources_map_to_owned_bytes(py, &value)?
                     .map(|x|
-                        x.into_iter().map(|(k, v)| (Cow::Owned(k.to_owned()), Cow::Owned(v.to_owned()))).collect()
+                        x.into_iter().map(|(k, v)| (Cow::Owned(k), Cow::Owned(v))).collect()
                     );
 
             Ok(())
@@ -1258,14 +1376,14 @@ py_class!(pub class OxidizedResource |py| {
 
     @property def shared_library_dependency_names(&self) -> PyResult<Option<Vec<String>>> {
         Ok(self.resource(py).borrow().shared_library_dependency_names.as_ref().map(|x| {
-            x.into_iter().map(|v| v.to_string()).collect()
+            x.iter().map(|v| v.to_string()).collect()
         }))
     }
 
     @shared_library_dependency_names.setter def set_shared_library_dependency_names(&self, value: Option<Option<Vec<String>>>) -> PyResult<()> {
         if let Some(value) = value {
             self.resource(py).borrow_mut().shared_library_dependency_names =
-                value.map(|x| x.into_iter().map(|v| Cow::Owned(v.to_owned())).collect());
+                value.map(|x| x.into_iter().map(Cow::Owned).collect());
 
             Ok(())
         } else {
@@ -1274,10 +1392,10 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_module_source(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_module_source.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_module_source.as_ref().map_or_else(
             || Ok(py.None()),
             |x| path_to_pathlib_path(py, x)
-        )?)
+        )
     }
 
     @relative_path_module_source.setter def set_relative_path_module_source(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1293,10 +1411,10 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_module_bytecode(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_module_bytecode.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_module_bytecode.as_ref().map_or_else(
             || Ok(py.None()),
             |x| path_to_pathlib_path(py, x)
-        )?)
+        )
     }
 
     @relative_path_module_bytecode.setter def set_relative_path_module_bytecode(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1312,10 +1430,10 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_module_bytecode_opt1(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_module_bytecode_opt1.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_module_bytecode_opt1.as_ref().map_or_else(
             || Ok(py.None()),
             |x| path_to_pathlib_path(py, x)
-        )?)
+        )
     }
 
     @relative_path_module_bytecode_opt1.setter def set_relative_path_module_bytecode_opt1(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1331,10 +1449,10 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_module_bytecode_opt2(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_module_bytecode_opt2.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_module_bytecode_opt2.as_ref().map_or_else(
             || Ok(py.None()),
             |x| path_to_pathlib_path(py, x)
-        )?)
+        )
     }
 
     @relative_path_module_bytecode_opt2.setter def set_relative_path_module_bytecode_opt2(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1350,10 +1468,10 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_extension_module_shared_library(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_extension_module_shared_library.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_extension_module_shared_library.as_ref().map_or_else(
             || Ok(py.None()),
             |x| path_to_pathlib_path(py, x)
-        )?)
+        )
     }
 
     @relative_path_extension_module_shared_library.setter def set_relative_path_extension_module_shared_library(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1369,7 +1487,7 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_package_resources(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_package_resources.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_package_resources.as_ref().map_or_else(
             || Ok(py.None()),
             |x| -> PyResult<PyObject> {
                 let res = PyDict::new(py);
@@ -1380,7 +1498,7 @@ py_class!(pub class OxidizedResource |py| {
 
                 Ok(res.into_object())
             }
-        )?)
+        )
     }
 
     @relative_path_package_resources.setter def set_relative_path_package_resources(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1388,7 +1506,7 @@ py_class!(pub class OxidizedResource |py| {
             self.resource(py).borrow_mut().relative_path_package_resources =
                 pyobject_optional_resources_map_to_pathbuf(py, &value)?
                     .map(|x|
-                        x.into_iter().map(|(k, v)| (Cow::Owned(k.to_owned()), Cow::Owned(v.to_owned()))).collect()
+                        x.into_iter().map(|(k, v)| (Cow::Owned(k), Cow::Owned(v))).collect()
                     );
 
             Ok(())
@@ -1398,7 +1516,7 @@ py_class!(pub class OxidizedResource |py| {
     }
 
     @property def relative_path_distribution_resources(&self) -> PyResult<PyObject> {
-        Ok(self.resource(py).borrow().relative_path_distribution_resources.as_ref().map_or_else(
+        self.resource(py).borrow().relative_path_distribution_resources.as_ref().map_or_else(
             || Ok(py.None()),
             |x| -> PyResult<PyObject> {
                 let res = PyDict::new(py);
@@ -1409,7 +1527,7 @@ py_class!(pub class OxidizedResource |py| {
 
                 Ok(res.into_object())
             }
-        )?)
+        )
     }
 
     @relative_path_distribution_resources.setter def set_relative_path_distribution_resources(&self, value: Option<PyObject>) -> PyResult<()> {
@@ -1417,7 +1535,7 @@ py_class!(pub class OxidizedResource |py| {
             self.resource(py).borrow_mut().relative_path_distribution_resources =
                 pyobject_optional_resources_map_to_pathbuf(py, &value)?
                     .map(|x|
-                        x.into_iter().map(|(k, v)| (Cow::Owned(k.to_owned()), Cow::Owned(v.to_owned()))).collect()
+                        x.into_iter().map(|(k, v)| (Cow::Owned(k), Cow::Owned(v))).collect()
                     );
 
             Ok(())
@@ -1436,7 +1554,7 @@ pub fn resource_to_pyobject(py: Python, resource: &Resource<u8>) -> PyResult<PyO
 }
 
 #[inline]
-pub fn pyobject_to_resource(py: Python, resource: OxidizedResource) -> Resource<u8> {
+pub(crate) fn pyobject_to_resource(py: Python, resource: OxidizedResource) -> Resource<u8> {
     resource.resource(py).borrow().clone()
 }
 
