@@ -3,6 +3,7 @@
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use {
+    super::{default_interpreter_config, set_sys_paths, PYTHON_INTERPRETER_PATH},
     crate::{MainPythonInterpreter, OxidizedPythonInterpreterConfig},
     cpython::{ObjectProtocol, PyBytes, PyList, PyObject, PyString, PyStringData},
     python3_sys as pyffi,
@@ -22,14 +23,14 @@ use std::os::windows::ffi::OsStringExt;
 
 #[cfg(target_family = "unix")]
 fn get_unicode_argument() -> OsString {
-    // 中文
+    // 中文 = U+4e2d / 20013 + U+6587 / 25991
     OsString::from_vec([0xe4, 0xb8, 0xad, 0xe6, 0x96, 0x87].to_vec())
 }
 
 #[cfg(target_family = "windows")]
 fn get_unicode_argument() -> OsString {
     // 中文
-    OsString::from_wide(&[0x2d4e, 0x8765])
+    OsString::from_wide(&[20013, 25991])
 }
 
 fn reprs(py: cpython::Python, container: &PyObject) -> cpython::PyResult<Vec<String>> {
@@ -41,10 +42,8 @@ fn reprs(py: cpython::Python, container: &PyObject) -> cpython::PyResult<Vec<Str
 }
 
 fn assert_importer(oxidized: bool, filesystem: bool) {
-    let mut config = OxidizedPythonInterpreterConfig::default();
-    // Otherwise the Rust arguments are interpreted as Python arguments.
-    config.interpreter_config.parse_argv = Some(false);
-    config.set_missing_path_configuration = false;
+    let mut config = default_interpreter_config();
+
     config.oxidized_importer = oxidized;
     config.filesystem_importer = filesystem;
     let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -54,14 +53,35 @@ fn assert_importer(oxidized: bool, filesystem: bool) {
     let meta_path_reprs = reprs(py, &sys.get(py, "meta_path").unwrap()).unwrap();
     let path_hook_reprs = reprs(py, &sys.get(py, "path_hooks").unwrap()).unwrap();
     const PATH_HOOK_REPR: &str = "built-in method path_hook of OxidizedFinder object";
+
+    // OxidizedFinder should be installed sys.meta_path and sys.path_hooks as first
+    // element when enabled. Its presence also replaced BuiltinImporter and
+    // FrozenImporter.
     if oxidized {
         assert!(meta_path_reprs[0].contains("OxidizedFinder"));
+        assert!(path_hook_reprs[0].contains(PATH_HOOK_REPR));
+
+        assert!(meta_path_reprs
+            .iter()
+            .all(|s| !s.contains("_frozen_importlib.BuiltinImporter")));
+        assert!(meta_path_reprs
+            .iter()
+            .all(|s| !s.contains("_frozen_importlib.FrozenImporter")));
     } else {
         assert!(meta_path_reprs
             .iter()
             .all(|s| !s.contains("OxidizedFinder")));
         assert!(path_hook_reprs.iter().all(|s| !s.contains(PATH_HOOK_REPR)));
+
+        assert!(meta_path_reprs
+            .iter()
+            .any(|s| s.contains("_frozen_importlib.BuiltinImporter")));
+        assert!(meta_path_reprs
+            .iter()
+            .any(|s| s.contains("_frozen_importlib.FrozenImporter")));
     }
+
+    // PathFinder should only be present when filesystem importer is enabled.
     if filesystem {
         assert!(meta_path_reprs
             .last()
@@ -71,20 +91,13 @@ fn assert_importer(oxidized: bool, filesystem: bool) {
         assert!(meta_path_reprs
             .iter()
             .all(|s| !s.contains("_frozen_importlib_external.PathFinder")));
-        assert!(path_hook_reprs.iter().all(|s| !s.contains(PATH_HOOK_REPR)));
-    }
-    if oxidized && filesystem {
-        assert!(path_hook_reprs.last().unwrap().contains(PATH_HOOK_REPR));
     }
 }
 
 rusty_fork_test! {
     #[test]
     fn test_default_interpreter() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let config = default_interpreter_config();
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
         let py = interp.acquire_gil();
@@ -128,13 +141,9 @@ rusty_fork_test! {
 
     #[test]
     fn test_isolated_interpreter() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
+        let mut config = default_interpreter_config();
         config.interpreter_config.profile = PythonInterpreterProfile::Isolated;
-        // This allows us to pick up the default paths from the Python install
-        // detected by python3_sys. Without this, sys.path and other paths reference
-        // directories next to the Rust test executable, and there is no Python stdlib
-        // there.
-        config.set_missing_path_configuration = false;
+        set_sys_paths(&mut config);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -154,10 +163,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_allocator_default() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Default;
 
@@ -168,10 +174,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_allocator_rust() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Rust;
         config.allocator_raw = true;
@@ -186,10 +189,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_allocator_rust_pymalloc_arena() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Rust;
         config.allocator_raw = true;
@@ -201,13 +201,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Rust);
     }
 
-    #[cfg(feature = "jemalloc")]
+    #[cfg(feature = "jemalloc-sys")]
     #[test]
     fn test_allocator_jemalloc() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Jemalloc;
         config.allocator_raw = true;
@@ -220,13 +217,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Jemalloc);
     }
 
-    #[cfg(feature = "jemalloc")]
+    #[cfg(feature = "jemalloc-sys")]
     #[test]
     fn test_allocator_jemalloc_pymalloc_arena() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Jemalloc;
         config.allocator_raw = true;
@@ -238,13 +232,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Jemalloc);
     }
 
-    #[cfg(feature = "mimalloc")]
+    #[cfg(feature = "libmimalloc-sys")]
     #[test]
     fn test_allocator_mimalloc() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Mimalloc;
         config.allocator_raw = true;
@@ -257,13 +248,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Mimalloc);
     }
 
-    #[cfg(feature = "mimalloc")]
+    #[cfg(feature = "libmimalloc-sys")]
     #[test]
     fn test_allocator_mimalloc_pymalloc_arena() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Mimalloc;
         config.allocator_raw = true;
@@ -275,13 +263,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Mimalloc);
     }
 
-    #[cfg(feature = "snmalloc")]
+    #[cfg(feature = "snmalloc-sys")]
     #[test]
     fn test_allocator_snmalloc() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Snmalloc;
         config.allocator_raw = true;
@@ -294,13 +279,10 @@ rusty_fork_test! {
         assert_eq!(interp.allocator.as_ref().unwrap().backend(), MemoryAllocatorBackend::Snmalloc);
     }
 
-    #[cfg(feature = "snmalloc")]
+    #[cfg(feature = "snmalloc-sys")]
     #[test]
     fn test_allocator_snmalloc_pymalloc_arena() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Snmalloc;
         config.allocator_raw = true;
@@ -314,10 +296,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_allocator_debug() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_debug = true;
 
@@ -326,10 +305,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_allocator_debug_custom_backend() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
 
         config.allocator_backend = MemoryAllocatorBackend::Rust;
         config.allocator_raw = true;
@@ -367,10 +343,9 @@ rusty_fork_test! {
     /// sys.argv is initialized using the Rust process's arguments by default.
     #[test]
     fn test_argv_default() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
+        // Undo defaults from default_interpreter_config().
+        config.argv = None;
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -389,19 +364,15 @@ rusty_fork_test! {
     /// `OxidizedPythonInterpreterConfig.interpreter_config.argv` is respected.
     #[test]
     fn test_argv_respect_interpreter_config() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-
+        let mut config = default_interpreter_config();
         // .argv expands to current process args by default. But setting
         // .interpreter_config.argv overrides this behavior.
-        config.argv = None;
         config.interpreter_config.argv = Some(vec![
-            OsString::from("prog"),
+            config.argv.as_ref().unwrap()[0].clone(),
             OsString::from("arg0"),
             OsString::from("arg1"),
         ]);
+        config.argv = None;
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -413,21 +384,16 @@ rusty_fork_test! {
             .unwrap()
             .extract::<Vec<String>>(py)
             .unwrap();
-        assert_eq!(argv, vec!["prog", "arg0", "arg1"]);
+        assert_eq!(argv, vec![PYTHON_INTERPRETER_PATH, "arg0", "arg1"]);
     }
 
     /// `OxidizedPythonInterpreterConfig.argv` can be used to define `sys.argv`.
     #[test]
     fn test_argv_override() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-        config.argv = Some(vec![
-            OsString::from("prog"),
-            OsString::from("foo"),
-            OsString::from("bar"),
-        ]);
+        let mut config = default_interpreter_config();
+        // keep argv[0] the same because it is used for path calculation.
+        config.argv.as_mut().unwrap().push(OsString::from("foo"));
+        config.argv.as_mut().unwrap().push(OsString::from("bar"));
         config.interpreter_config.argv = Some(vec![OsString::from("shoud-be-ignored")]);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -440,17 +406,13 @@ rusty_fork_test! {
             .unwrap()
             .extract::<Vec<String>>(py)
             .unwrap();
-        assert_eq!(argv, vec!["prog", "foo", "bar"]);
+        assert_eq!(argv, vec![PYTHON_INTERPRETER_PATH, "foo", "bar"]);
     }
 
     #[test]
     fn test_argvb_utf8() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-        config.argv = Some(vec![get_unicode_argument()]);
+        let mut config = default_interpreter_config();
+        config.argv.as_mut().unwrap().push(get_unicode_argument());
         config.argvb = true;
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -460,15 +422,15 @@ rusty_fork_test! {
 
         let argvb_raw = sys.get(py, "argvb").unwrap();
         let argvb = argvb_raw.cast_as::<PyList>(py).unwrap();
-        assert_eq!(argvb.len(py), 1);
+        assert_eq!(argvb.len(py), 2);
 
-        let value_raw = argvb.get_item(py, 0);
+        let value_raw = argvb.get_item(py, 1);
         let value_bytes = value_raw.cast_as::<PyBytes>(py).unwrap();
         assert_eq!(
             value_bytes.data(py).to_vec(),
             if cfg!(windows) {
-                // UTF-16.
-                b"\x4e\x2d\x65\x87".to_vec()
+                // UTF-16-LE.
+                b"\x2d\x4e\x87\x65".to_vec()
             } else {
                 // UTF-8.
                 b"\xe4\xb8\xad\xe6\x96\x87".to_vec()
@@ -478,12 +440,8 @@ rusty_fork_test! {
 
     #[test]
     fn test_argv_utf8() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-        config.argv = Some(vec![get_unicode_argument()]);
+        let mut config = default_interpreter_config();
+        config.argv.as_mut().unwrap().push(get_unicode_argument());
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -492,38 +450,22 @@ rusty_fork_test! {
 
         let argv_raw = sys.get(py, "argv").unwrap();
         let argv = argv_raw.cast_as::<PyList>(py).unwrap();
-        assert_eq!(argv.len(py), 1);
+        assert_eq!(argv.len(py), 2);
 
-        let value_raw = argv.get_item(py, 0);
+        let value_raw = argv.get_item(py, 1);
         let value_string = value_raw.cast_as::<PyString>(py).unwrap();
         match value_string.data(py) {
-            PyStringData::Utf8(b"\xe4\xb8\xad\xe6\x96\x87") => {
-                if cfg!(target_family = "unix") {
-                    assert!(true)
-                } else {
-                    assert!(false)
-                }
-            }
-            PyStringData::Utf8(b"\xe2\xb5\x8e\xe8\x9d\xa5") => {
-                if cfg!(target_family = "windows") {
-                    assert!(true)
-                } else {
-                    assert!(false)
-                }
-            }
+            PyStringData::Utf16(&[20013, 25991]) => {},
             value => assert!(false, "{:?}", value),
         }
     }
 
     #[test]
     fn test_argv_utf8_isolated() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
+        let mut config = default_interpreter_config();
         config.interpreter_config.profile = PythonInterpreterProfile::Isolated;
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-        config.set_missing_path_configuration = false;
-        config.argv = Some(vec![get_unicode_argument()]);
+        config.argv.as_mut().unwrap().push(get_unicode_argument());
+        set_sys_paths(&mut config);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -532,61 +474,40 @@ rusty_fork_test! {
 
         let argv_raw = sys.get(py, "argv").unwrap();
         let argv = argv_raw.cast_as::<PyList>(py).unwrap();
-        assert_eq!(argv.len(py), 1);
+        assert_eq!(argv.len(py), 2);
 
-        let value_raw = argv.get_item(py, 0);
+        let value_raw = argv.get_item(py, 1);
+        let value_string = value_raw.cast_as::<PyString>(py).unwrap();
 
-        // The cpython crate only converts to PyStringData if the internal
-        // representation is UTF-8 and will panic otherwise. Since we're using
-        // surrogates for the test string, `.data()` will panic. So let's poke
-        // at the CPython APIs to get what we need.
-        //
-        // Unfortunately, python3_sys doesn't expose `PyUnicode_Type` to us,
-        // since `PyUnicode_KIND` is a macro. Neither do we have bindings to
-        // `PyUnicode_DATA`.
-        assert_eq!(unsafe {
-            pyffi::PyUnicode_GetLength(value_raw.as_ptr())
-        }, if cfg!(target_family = "windows") {
-            2
-        } else {
-            6
-        });
-
-        let encoded_raw = unsafe {
-            PyObject::from_owned_ptr(
-                py,
-                pyffi::PyUnicode_AsEncodedString(
-                    value_raw.as_ptr(),
-                    b"utf-8\0".as_ptr() as *const _,
-                    b"surrogatepass\0".as_ptr() as *const _,
-                )
-            )
-        };
-        let encoded_bytes = encoded_raw.cast_as::<PyBytes>(py).unwrap();
-        let encoded_data = encoded_bytes.data(py);
-
-        if cfg!(target_family = "windows") {
-            assert_eq!(encoded_data.len(), 6);
-            assert_eq!(encoded_data, b"\xe2\xb5\x8e\xe8\x9d\xa5");
-        } else {
-            // This is very wrong.
-            assert_eq!(encoded_data.len(), 18);
-            assert_eq!(
-                String::from_utf8(encoded_data.to_owned()).unwrap_err().to_string(),
-                "invalid utf-8 sequence of 1 bytes from index 0",
-            );
+        // The result in isolated mode without configure_locale is kinda wonky.
+        match value_string.data(py) {
+            // This is the correct value.
+            PyStringData::Utf16(&[20013, 25991]) => {
+                if cfg!(any(target_family = "windows", target_os = "macos")) {
+                    assert!(true);
+                } else {
+                    assert!(false);
+                }
+            }
+            // This is some abomination.
+            PyStringData::Utf16(&[56548, 56504, 56493, 56550, 56470, 56455]) => {
+                if cfg!(target_family = "unix") {
+                    assert!(true);
+                } else {
+                    assert!(false);
+                }
+            }
+            value => assert!(false, "unexpected string data: {:?}", value),
         }
     }
 
     #[test]
     fn test_argv_utf8_isolated_configure_locale() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
+        let mut config = default_interpreter_config();
         config.interpreter_config.profile = PythonInterpreterProfile::Isolated;
         config.interpreter_config.configure_locale = Some(true);
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
-        config.argv = Some(vec![get_unicode_argument()]);
+        config.argv.as_mut().unwrap().push(get_unicode_argument());
+        set_sys_paths(&mut config);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -595,38 +516,20 @@ rusty_fork_test! {
 
         let argv_raw = sys.get(py, "argv").unwrap();
         let argv = argv_raw.cast_as::<PyList>(py).unwrap();
-        assert_eq!(argv.len(py), 1);
+        assert_eq!(argv.len(py), 2);
 
-        let value_raw = argv.get_item(py, 0);
+        let value_raw = argv.get_item(py, 1);
+        let value_string = value_raw.cast_as::<PyString>(py).unwrap();
 
-        assert_eq!(unsafe {
-            pyffi::PyUnicode_GetLength(value_raw.as_ptr())
-        }, 2);
-
-        let encoded_raw = unsafe {
-            PyObject::from_owned_ptr(
-                py,
-                pyffi::PyUnicode_AsEncodedString(
-                    value_raw.as_ptr(),
-                    b"utf-8\0".as_ptr() as *const _,
-                    b"strict\0".as_ptr() as *const _,
-                )
-            )
-        };
-        let encoded_bytes = encoded_raw.cast_as::<PyBytes>(py).unwrap();
-        let encoded_data = encoded_bytes.data(py);
-        assert_eq!(encoded_data, if cfg!(target_family = "windows") {
-            b"\xe2\xb5\x8e\xe8\x9d\xa5"
-        } else {
-            b"\xe4\xb8\xad\xe6\x96\x87"
-        });
+        match value_string.data(py) {
+            PyStringData::Utf16(&[20013, 25991]) => {},
+            value => assert!(false, "unexpected string data: {:?}", value),
+        }
     }
 
     #[test]
     fn test_tcl_library_origin() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
+        let mut config = default_interpreter_config();
         config.tcl_library = Some(PathBuf::from("$ORIGIN").join("lib").join("tcl8.6"));
 
         let config = config.resolve().unwrap();
@@ -643,10 +546,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_dev_mode() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.development_mode = Some(true);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -660,11 +560,9 @@ rusty_fork_test! {
 
     #[test]
     fn test_use_environment() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.use_environment = Some(false);
+        set_sys_paths(&mut config);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
 
@@ -677,10 +575,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_utf8_mode() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.utf8_mode = Some(true);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -694,10 +589,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_bytes_warning_warn() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.bytes_warning = Some(BytesWarning::Warn);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -711,10 +603,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_bytes_warning_raise() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.bytes_warning = Some(BytesWarning::Raise);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -728,10 +617,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_optimization_level_one() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.optimization_level = Some(BytecodeOptimizationLevel::One);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -745,10 +631,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_optimization_level_two() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.optimization_level = Some(BytecodeOptimizationLevel::Two);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -762,10 +645,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_inspect() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.inspect = Some(true);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -779,10 +659,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_interactive() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.interactive = Some(true);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -796,10 +673,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_quiet() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.quiet = Some(true);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -813,10 +687,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_site_import() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.site_import = Some(false);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -830,10 +701,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_user_site_directory() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.user_site_directory = Some(false);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
@@ -847,10 +715,7 @@ rusty_fork_test! {
 
     #[test]
     fn test_write_bytecode() {
-        let mut config = OxidizedPythonInterpreterConfig::default();
-        // Otherwise the Rust arguments are interpreted as Python arguments.
-        config.interpreter_config.parse_argv = Some(false);
-        config.set_missing_path_configuration = false;
+        let mut config = default_interpreter_config();
         config.interpreter_config.write_bytecode = Some(false);
 
         let mut interp = MainPythonInterpreter::new(config).unwrap();
