@@ -2,6 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
+import sys
 import unittest
 
 from oxidized_importer import OxidizedFinder
@@ -33,14 +34,25 @@ class TestImporterConstruction(unittest.TestCase):
 
     def test_no_indices(self):
         f = OxidizedFinder()
-        f.index_bytes(b"pyembed\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00")
+        f.index_bytes(
+            b"pyembed\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+        )
 
     def test_origin_bad_value(self):
         with self.assertRaises(TypeError):
             OxidizedFinder(relative_path_origin=True)
 
+    def test_path_hook_base_str(self):
+        f = OxidizedFinder()
+        # We can't make reasonable assumptions about the value of path_hook_base_str
+        # because the test environment does weird things with sys.argv and
+        # hence sys.executable. We have to rely on other tests for the
+        # correctness of this value.
+        self.assertIsInstance(f.path_hook_base_str, str)
+
     def test_origin(self):
-        OxidizedFinder(relative_path_origin="/path/to/origin")
+        f = OxidizedFinder(relative_path_origin="/path/to/origin")
+        self.assertEqual(f.origin, "/path/to/origin")
 
 
 if __name__ == "__main__":
