@@ -15,9 +15,12 @@ class TestImporterModule(unittest.TestCase):
             {
                 "decode_source",
                 "find_resources_in_path",
+                "pkg_resources_find_distributions",
+                "register_pkg_resources",
                 "OxidizedDistribution",
                 "OxidizedFinder",
                 "OxidizedPathEntryFinder",
+                "OxidizedPkgResourcesProvider",
                 "OxidizedResourceCollector",
                 "OxidizedResourceReader",
                 "OxidizedResource",
@@ -56,7 +59,9 @@ class TestImporterModule(unittest.TestCase):
                 "indexed_resources",
                 "invalidate_caches",
                 "iter_modules",
+                "origin",
                 "path_hook",
+                "path_hook_base_str",
                 "serialize_indexed_resources",
             },
         )
